package WebService::PayPal::PaymentsAdvanced::Role::HasPayPal;
$WebService::PayPal::PaymentsAdvanced::Role::HasPayPal::VERSION = '0.000008';
use Moo::Role;

use Types::Standard qw( Str );

has reference_transaction_id => (
    is       => 'lazy',
    isa      => Str,
    init_arg => undef,
    default  => sub { shift->params->{BAID} },
);

1;

__END__

=pod

=encoding UTF-8

=head1 NAME

WebService::PayPal::PaymentsAdvanced::Role::HasPayPal

=head1 VERSION

version 0.000008

=head1 AUTHOR

Olaf Alders <olaf@wundercounter.com>

=head1 COPYRIGHT AND LICENSE

This software is Copyright (c) 2015 by MaxMind, Inc..

This is free software, licensed under:

  The Artistic License 2.0 (GPL Compatible)

=cut
